@@ -1,4 +1,4 @@
 """Provide CLI for pipen"""
 
-from ._hooks import cli_plugin
+from ._hooks import CLIPlugin
 from ._main import main
